import { BasicEvent } from "@skeldjs/events";
import { VotingCompleteMessage } from "@skeldjs/protocol";
import { MeetingHud } from "../../objects";
import { Hostable } from "../../Hostable";
import { PlayerVoteState } from "../../misc/PlayerVoteState";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { MeetingHudEvent } from "./MeetingHudEvent";
/**
 * Emitted when a meeting is finished, and when the ejected player is determined.
 */
export declare class MeetingHudVotingCompleteEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, MeetingHudEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly meetinghud: MeetingHud<RoomType>;
    readonly message: VotingCompleteMessage | undefined;
    /**
     * Whether a tie was reached in votes.
     */
    readonly tie: boolean;
    /**
     * The voting state of every player in the meeting.
     */
    readonly voteStates: Map<number, PlayerVoteState<RoomType>>;
    /**
     * The player that was ejected. Undefined if a tie was reached
     * or if players voted to skip.
     */
    readonly ejected?: PlayerData<RoomType> | undefined;
    static eventName: "meeting.votingcomplete";
    eventName: "meeting.votingcomplete";
    constructor(room: RoomType, meetinghud: MeetingHud<RoomType>, message: VotingCompleteMessage | undefined, 
    /**
     * Whether a tie was reached in votes.
     */
    tie: boolean, 
    /**
     * The voting state of every player in the meeting.
     */
    voteStates: Map<number, PlayerVoteState<RoomType>>, 
    /**
     * The player that was ejected. Undefined if a tie was reached
     * or if players voted to skip.
     */
    ejected?: PlayerData<RoomType> | undefined);
}
