import { BasicEvent } from "@skeldjs/events";
import { CheckMurderMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player is attempting to murder another player, and is requesting
 * the host to verify the attempt and actually murder the player. Only admitted
 * if the client is the host.
 *
 * This event is useful if you want to prevent a murder from actually happening,
 * before it happens. Therefore this event doesn't guarantee that the victim is
 * actually dead, see {@link PlayerMurderEvent} to listen for that.
 */
export declare class PlayerCheckMurderEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: CheckMurderMessage | undefined;
    /**
     * The other player that the player is attempting to murder.
     */
    readonly victim: PlayerData<RoomType>;
    /**
     * Whether or not this murder would normally be considered valid and thus
     * the player be murdered.
     */
    readonly isValid: boolean;
    static eventName: "player.checkmurder";
    eventName: "player.checkmurder";
    private _alteredPlayer;
    private _alteredVictim;
    private _alteredIsValid;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: CheckMurderMessage | undefined, 
    /**
     * The other player that the player is attempting to murder.
     */
    victim: PlayerData<RoomType>, 
    /**
     * Whether or not this murder would normally be considered valid and thus
     * the player be murdered.
     */
    isValid: boolean);
    /**
     * The player that will murder the victim instead, if altered.
     */
    get alteredPlayer(): PlayerData<RoomType>;
    /**
     * Change the player that will actually murder the victim.
     */
    setPlayer(player: PlayerData<RoomType>): void;
    /**
     * The player that will murdered instead, if altered.
     */
    get alteredVictim(): PlayerData<RoomType>;
    /**
     * Change the player that will actually be murdered.
     * @param victim The player to murder.
     */
    setVictim(victim: PlayerData<RoomType>): void;
    /**
     * Whether or not this murder will be considered valid instead, if altered.
     */
    get alteredIsValid(): boolean;
    /**
     * Change whether this murder should be consider valid. If valid, ths player
     * will indeed be murdered.
     * @param isValid Whether or not this murder should be considered valid.
     */
    setValid(isValid: boolean): void;
}
